@@ -1,35 +1,41 @@
-package Huawei::Healthcheck;
+package Huawei::Healthchecker;
 
-our $VERSION = "0.02";
+#版本信息
+our $VERSION = "0.03";
 
 use 5.012;
 use warnings;
 use Data::Dumper;
 
+use Carp;
 use Net::Compare;
+
 use Exporter;
+
+#继承parent相关变量
 use parent 'Exporter';
 
-our @EXPORT = qw 'health_check';
+#自动导出健康检查函数
+our @EXPORT = qw(health_check);
 
 #设置华为设备通用健康检查哈希数据模型
 my $attr = {
     'hardware' => {
-        'version'            => 'dis version',
-        'disk_status'        => 'dis health',
-        'temperature_status' => 'dis device temperature all',
-        'alarm_status'       => 'dis device alarm hardware',
-        'fan_status'         => 'dis device fan',
+        'device_version'     => 'dis device',
         'module_status'      => 'dis device',
-        'power_status'       => 'dis device power'
+        'power_status'       => 'dis device power',
+        'disk_status'        => 'dis health',
+        'fan_status'         => 'dis device fan',
+        'alarm_status'       => 'dis device alarm hardware',
+        'temperature_status' => 'dis device temperature all',
     },
     'status' => {
-        'err_down_status'  => 'dis error-down recovery',
-        'memory_status'    => 'dis memory',
-        'eth_trunk_status' => 'dis eth-trunk',
         'cpu_status'       => 'dis cpu',
+        'memory_status'    => 'dis memory',
         'ntp_status'       => 'dis ntp status',
-        'vrrp_status'      => 'dis vrrp'
+        'vrrp_status'      => 'dis vrrp',
+        'eth_trunk_status' => 'dis eth-trunk',
+        'err_down_status'  => 'dis error-down recovery',
     }
 };
 
@@ -45,8 +51,8 @@ my $status = $attr->{"status"};
 sub health_check {
     my $config = shift;
     my $rev    = status_check($config);
-    my score   = calculate_score($rev);
-    return [ $rev, $score ];
+    my $score  = calculate_score($rev);
+    return [ $rev, { "score" => $score } ];
 }
 
 #-------------------------------------------------------------------------
@@ -86,7 +92,7 @@ sub status_check {
     #-------------------------------------------------------------------------
     # 网络设备-硬件运行状态巡检判断
     #-------------------------------------------------------------------------
-    my $device_info        = device_verison($device_version);
+    my $device_info        = device_version($device_version);
     my $module_status      = module_status($device_module);
     my $power_status       = power_status($device_power);
     my $disk_status        = disk_status($device_disk);
@@ -143,7 +149,8 @@ sub calculate_score {
     my $status = $rev->{"status"};
 
     #设备巡检项总数
-    my $attr_count = keys %{$hardware} + keys %{$status};
+    my $attr_count
+        = ( scalar( keys %{$hardware} ) ) + ( scalar( keys %{$status} ) );
 
     #硬件巡检通过项计数
     my $hardware_attr;
@@ -155,8 +162,7 @@ sub calculate_score {
         }
         else {
             my $alarm = $ret->{"alarm"};
-            $alarm = join( "", keys %{$alert} )
-                if ( $alarm eq "info" ) {
+            if ( $alarm eq "info" ) {
                 $hardware_attr -= 0.1;
             }
             elsif ( $alarm eq "alert" ) {
@@ -178,8 +184,7 @@ sub calculate_score {
         }
         else {
             my $alarm = $ret->{"alarm"};
-            $alarm = join( "", keys %{$alert} )
-                if ( $alarm eq "info" ) {
+            if ( $alarm eq "info" ) {
                 $status_attr -= 0.1;
             }
             elsif ( $alarm eq "alert" ) {
@@ -509,7 +514,7 @@ sub temperature_status {
 #-------------------------------------------------------------------------
 # 网络设备-硬件运行状态巡检 -- 硬件存储告警检查
 #-------------------------------------------------------------------------
-sub storage_status {
+sub disk_status {
 
     #接收巡检命令行输出
     my $rev = shift;
@@ -621,10 +626,10 @@ sub cpu_status {
                 if $usage >= 60;
 
             #设置越线惩罚机制
-            if ( 60 <= $usage < 70 ) {
+            if ( 60 <= $usage && $usage < 70 ) {
                 $result->{"alarm"} = "info";
             }
-            elsif ( 70 <= $usage < 80 ) {
+            elsif ( 70 <= $usage && $usage < 80 ) {
                 $result->{"alarm"} = "alert";
             }
             elsif ( $usage >= 80 ) {
@@ -653,10 +658,11 @@ sub cpu_status {
             $max_usage =~ s/\%//;
 
             #写入异常状态
-            $result->{"alarm"}{"alert"}
-                = "cpu history usage is high: " . "$info[1]\%"
+            $result->{"log"} = "cpu history usage is high: " . "$info[1]\%"
                 if $max_usage > 85;
 
+            $result->{"alarm"} = "critic" if $max_usage > 85;
+
             #监控检查状态
             $result->{"health"} = "fail" if $max_usage > 85;
             last;
@@ -709,13 +715,13 @@ sub memory_status {
 
             #写入异常状态
             $result->{"log"} = "memory usage is high: " . $usage
-                if $usage > 60;
+                if ( $usage > 60 );
 
             #设置越线惩罚机制
-            if ( 60 <= $usage < 70 ) {
+            if ( 60 <= $usage && $usage < 70 ) {
                 $result->{"alarm"} = "info";
             }
-            elsif ( 70 <= $usage < 80 ) {
+            elsif ( 70 <= $usage && $usage < 80 ) {
                 $result->{"alarm"} = "alert";
             }
             elsif ( $usage >= 80 ) {
@@ -767,7 +773,6 @@ sub ntp_status {
             $status =~ s/(^\s+|\s+$)//;
 
             #写入异常状态
-            my $alarm = lc( $+{alarm} );
             $result->{"log"} = "ntp not synchronized"
                 if ( $status =~ /not/i );
             $result->{"alarm"} = "info";
@@ -823,7 +828,6 @@ sub vrrp_status {
             $status =~ s/(^\s+|\s+$)//;
 
             #写入异常状态
-            my $alarm = lc( $+{alarm} );
             $result->{"info"} = "vrrp not synchronized"
                 if ( $status =~ /not/i );
 
@@ -881,7 +885,6 @@ sub eth_trunk_status {
             $status =~ s/(^\s+|\s+$)//;
 
             #写入异常状态
-            my $alarm = lc( $+{alarm} );
             $result->{"log"} = "eth-trunk is Abnormal"
                 if ( $status =~ /not/i );
 
@@ -939,7 +942,6 @@ sub err_down_status {
             $status =~ s/(^\s+|\s+$)//;
 
             #写入异常状态
-            my $alarm = lc( $+{alarm} );
             $result->{"log"} = "interface in error-down"
                 if ( $status =~ /not/i );
 
@@ -956,3 +958,4 @@ sub err_down_status {
 }
 
 1;
+
